<?php
declare(strict_types=1);

namespace FiloBlu\Refilo\Test\Unit\Heler;

use FiloBlu\Refilo\Helper\Indexer;
use Magento\Framework\App\ResourceConnection;
use PHPUnit\Framework\TestCase;

/**
 * Class IndexerTest
 * @package FiloBlu\Refilo\Test\Unit\Heler
 */
class IndexerTest extends TestCase
{

    /**
     * @dataProvider getIntervals
     * @param $intervals
     * @param $expect
     */
    public function testGetDeletedEntityIds($intervals, $expect)
    {
        $resourceConnection = $this->createMock(ResourceConnection::class);

        $helper = new Indexer($resourceConnection);
        $result = $helper->getDeletedEntityIdsByIntervals($intervals);

        sort($result);
        sort($expect);
        static::assertEquals($result, $expect);
    }

    /**
     * @return array[]
     */
    public function getIntervals()
    {
        return [
            [
                [
                    ['start' => 1, 'end' => 10],
                    ['start' => 861, 'end' => 862],
                    ['start' => 864, 'end' => 864],
                ], [2, 3, 4, 5, 6, 7, 8, 9]
            ],
            [
                [
                    ['start' => 19, 'end' => 21],
                    ['start' => 6425, 'end' => 6427]
                ], [20, 6426]
            ],
            [
                [
                    ['start' => 10, 'end' => 11]
                ],
                []
            ],
            [
                [
                    ['start' => 11, 'end' => 11]
                ],
                []
            ],
            [
                [
                    ['start' => 10, 'end' => 12]
                ],
                [11]
            ]
        ];

    }

    protected function setUp(): void
    {
    }

    protected function tearDown(): void
    {
    }
}
